#
# spec file for package SoQt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 20
%define         realver 1.6.2
Name:           SoQt
Version:        1.6.2
Release:        1.3
Summary:        A library which provides the glue between Coin and Qt
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://coin3d.github.io/SoQt/html/
Source:         https://github.com/coin3d/soqt/releases/download/v%{version}/soqt-%{version}-src.tar.gz
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(coin)

%description
The core rendering library Coin is a multiplatform high-level 3D graphics
library with a C++ API. Coin uses OpenGL for accelerated rendering, while
providing a higher abstraction level, 3D interactivity, and many complex
optimization features for fast rendering that are transparent for the
application programmer, thus facilitating the development of interactive 3D
applications and greatly increasing productivity.

%package devel
Summary:        Development files for SoQt
Group:          Development/Libraries/C and C++
Requires:       libSoQt%{sover}
Requires:       libpng-devel
Requires:       cmake(Qt5Gui)
Requires:       cmake(Qt5OpenGL)
Requires:       cmake(Qt5Widgets)
Requires:       cmake(coin)

%description devel
By using the combination of Coin, Qt and SoQt for your 3D applications, you
have a framework for writing completely portable software across the whole range
of UNIX, Linux, Microsoft Windows and Mac OS X operating systems. Coin, Qt and
SoQt makes this possible from a 100% common codebase, which means there is a
minimum of hassle for developers when working on multiplatform software, with
the resulting large gains in productivity.

%package doc
Summary:        API documentation for SoQt
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
By using the combination of Coin, Qt and SoQt for your 3D applications, you
have a framework for writing completely portable software across the whole range
of UNIX, Linux, Microsoft Windows and Mac OS X operating systems. Coin, Qt and
SoQt makes this possible from a 100% common codebase, which means there is a
minimum of hassle for developers when working on multiplatform software, with
the resulting large gains in productivity.

%package -n libSoQt%{sover}
Summary:        A library which provides the glue between Coin and Qt
Group:          System/Libraries

%description -n libSoQt%{sover}
By using the combination of Coin, Qt and SoQt for your 3D applications, you
have a framework for writing completely portable software across the whole range
of UNIX, Linux, Microsoft Windows and Mac OS X operating systems. Coin, Qt and
SoQt makes this possible from a 100% common codebase, which means there is a
minimum of hassle for developers when working on multiplatform software, with
the resulting large gains in productivity.

%prep
%setup -q -n soqt
# Fix broken Qt4 requires in pkgconfig file
sed -i -e '/Requires:/ s/Qt\([^ ,]*\)/Qt5\1/g' SoQt.pc.cmake.in

%build
# default __builddir clashes with existing "build" dir
%global __builddir my_build
%cmake .. \
      -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} \
      -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir}/Coin4/ \
      -DSOQT_BUILD_DOCUMENTATION=TRUE \
      -DSOQT_BUILD_DOC_MAN=TRUE \
      %{nil}
%cmake_build

%install
%cmake_install

%fdupes %{buildroot}%{_prefix}

%post -n libSoQt%{sover} -p /sbin/ldconfig
%postun -n libSoQt%{sover} -p /sbin/ldconfig

%files -n libSoQt%{sover}
%license COPYING
%doc AUTHORS README
%{_libdir}/libSoQt.so.%{sover}*
%{_libdir}/libSoQt.so.*

%files doc
%{_docdir}/SoQt

%files devel
%{_datadir}/SoQt
%dir %{_includedir}/Coin4/Inventor/Qt
%{_includedir}/Coin4/Inventor/Qt/*
%{_libdir}/cmake/%{name}-%{realver}/
%{_libdir}/libSoQt.so
%{_libdir}/pkgconfig/SoQt.pc
%{_mandir}/man3/*

%changelog
* Sat Jan  6 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 1.6.2:
  * bugfixes:
    + Fixed numerous typos found with codespell
- update to 1.6.1:
  * new:
    + Home of Coin3d organization has been changed to
    https://github.com/coin3d
    + Added support for Qt6
  * bugfixes:
    + Fixed numerous documentation issues
    + Added SOQT_BUILD_TESTS option to control building of test
    code (default: ON)
    + Fix hidpi black screen issue
    + Fix broken SoQt.pc.cmake.in. Added -lSoQt
    + Fix wrong glwidget geometry size for Qt4
    + Add handling for background color RGBA
* Tue Feb 22 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Adapt for Coin4, remove
  0001-Use-a-Find-module-to-find-older-Coin-versions.patch
- Fix License, SoQt since 1.6.0 is BSD-3-Clause
- Drop irrelevant SoQt-man3.patch
* Mon Mar  8 2021 Dirk Müller <dmueller@suse.com>
- update to final 1.6.0:
  * see https://raw.githubusercontent.com/coin3d/soqt/SoQt-1.6.0/NEWS
* Mon Nov 25 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix invalid Requires: in pkgconfig file, replace Qt(4) with Qt5.
* Mon May 13 2019 Christophe Giboudeaux <christophe@krop.fr>
- Drop invalid requires of doc sub package
* Mon May 13 2019 Christophe Giboudeaux <christophe@krop.fr>
- Run spec-cleaner
- Install the license file
- Add 0001-Use-a-Find-module-to-find-older-Coin-versions.patch
  This will allow using the stable Coin package to build the SoQt
  snapshot.
- Drop fix-cmake-install.patch
* Mon May  6 2019 Adrian Schröter <adrian@suse.de>
- update to current snapshot
- fix URL, old coin3d.org site has been shut down
- using cmake build system now
* Tue Oct  9 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Cleanup spec file:
  - move soqt-default.cfg to devel package, it is only used by soqt-config
  - make doc subpackage noarch
  - use %%_docdir
* Wed Aug  3 2016 jengelh@inai.de
- Rectify RPM groups. Use smp_mflags for parallel building.
  Drop redundant export CFLAGS lines. Rename %%soname to %%sover
  because it did not contain the soname.
* Tue Jul  5 2016 adrian@suse.de
- update to version 1.5.0
- use Qt4 instead of Qt3 ....
* Fri Nov  5 2010 malcolmlewis@opensuse.org
- Spec file fixes based on rpmlint report
* Thu Nov  4 2010 malcolmlewis@opensuse.org
- Fix Requires for devel package
* Thu Nov  4 2010 malcolmlewis@opensuse.org
- Spec file clean up
- Patches redone
* Sun Sep 28 2008 andrea@links2linux.de
- complete spec rewrite
* Sun Nov 18 2007 mvyskocil@suse.cz
- First release for OpenSuse Build Service
